@@ -52,6 +52,10 @@ pub(crate) use libc as c;
 #[cfg(not(windows))]
 pub(crate) mod fs;
 pub(crate) mod io;
+#[cfg(any(target_os = "android", target_os = "linux"))]
+#[cfg(feature = "io_uring")]
+#[cfg_attr(doc_cfg, doc(cfg(feature = "io_uring")))]
+pub(crate) mod io_uring;
 #[cfg(not(any(target_os = "redox", target_os = "wasi")))] // WASI doesn't support `net` yet.
 pub(crate) mod net;
 #[cfg(not(windows))]
@@ -65,19 +69,19 @@ pub(crate) mod time;
 
 /// If the host libc is glibc, return `true` if it is less than version 2.25.
 ///
-/// To restate and clarify, this function returning true does not mean the libc is glibc
-/// just that if it is glibc, it is less than version 2.25.
+/// To restate and clarify, this function returning true does not mean the libc
+/// is glibc just that if it is glibc, it is less than version 2.25.
 ///
 /// For now, this function is only available on Linux, but if it ends up being
 /// used beyond that, this could be changed to e.g. `#[cfg(unix)]`.
 #[cfg(all(unix, target_env = "gnu"))]
 pub(crate) fn if_glibc_is_less_than_2_25() -> bool {
-    // This is also defined inside `weak_or_syscall!` in imp/libc/rand/syscalls.rs, but
-    // it's not convenient to re-export the weak symbol from that macro, so we duplicate it at
-    // a small cost here.
+    // This is also defined inside `weak_or_syscall!` in
+    // imp/libc/rand/syscalls.rs, but it's not convenient to re-export the weak
+    // symbol from that macro, so we duplicate it at a small cost here.
     weak! { fn getrandom(*mut c::c_void, c::size_t, c::c_uint) -> c::ssize_t }
 
-    // glibc 2.25 has getrandom(), which is how we satisfy the API contract of this function.
-    // But, there are likely other libc versions which have it.
+    // glibc 2.25 has `getrandom`, which is how we satisfy the API contract of
+    // this function. But, there are likely other libc versions which have it.
     getrandom.get().is_none()
 }
