@@ -6,7 +6,6 @@
 #![allow(unsafe_code)]
 
 use super::super::c;
-use super::offsetof_sun_path;
 use crate::ffi::ZStr;
 use crate::{io, path};
 use core::convert::TryInto;
@@ -17,8 +16,8 @@ use core::mem::transmute;
 #[derive(Clone)]
 #[doc(alias = "sockaddr_un")]
 pub struct SocketAddrUnix {
-    pub(crate) unix: linux_raw_sys::general::sockaddr_un,
-    len: linux_raw_sys::general::socklen_t,
+    pub(crate) unix: c::sockaddr_un,
+    len: c::socklen_t,
 }
 
 impl SocketAddrUnix {
@@ -60,9 +59,9 @@ impl SocketAddrUnix {
         Ok(Self { unix, len })
     }
 
-    fn init() -> linux_raw_sys::general::sockaddr_un {
-        linux_raw_sys::general::sockaddr_un {
-            sun_family: linux_raw_sys::general::AF_UNIX as _,
+    fn init() -> c::sockaddr_un {
+        c::sockaddr_un {
+            sun_family: c::AF_UNIX as _,
             sun_path: [0; 108],
         }
     }
@@ -97,7 +96,7 @@ impl SocketAddrUnix {
     }
 
     #[inline]
-    pub(crate) fn addr_len(&self) -> linux_raw_sys::general::socklen_t {
+    pub(crate) fn addr_len(&self) -> c::socklen_t {
         self.len
     }
 
@@ -158,3 +157,13 @@ impl fmt::Debug for SocketAddrUnix {
 
 /// `struct sockaddr_storage` as a raw struct.
 pub type SocketAddrStorage = linux_raw_sys::general::sockaddr;
+
+/// Return the offset of the `sun_path` field of `sockaddr_un`.
+#[inline]
+pub(crate) fn offsetof_sun_path() -> usize {
+    let z = c::sockaddr_un {
+        sun_family: 0_u16,
+        sun_path: [0; 108],
+    };
+    (crate::as_ptr(&z.sun_path) as usize) - (crate::as_ptr(&z) as usize)
+}
